from quick_resto_API.quick_resto_interface import QuickRestoInterface

from quick_resto_API.operations_with_objects.modules.account_type_operations import AccountTypeOperations, AccountType
from quick_resto_API.operations_with_objects.modules.alcohol_dictionary_operations import AlcoholDictionaryOperations, AlcoholDictionary
from quick_resto_API.operations_with_objects.modules.alcohol_report_operations import AlcoholReportOperations, AlcoholReport
from quick_resto_API.operations_with_objects.modules.bonus_program_operations import BonusProgramOperations, BonusProgram
from quick_resto_API.operations_with_objects.modules.business_operations import BusinessOperations, Business
from quick_resto_API.operations_with_objects.modules.cancellation_operations import CancellationOperations, Cancellation
from quick_resto_API.operations_with_objects.modules.company_info_operations import CompanyInfoOperations,CompanyInfo
from quick_resto_API.operations_with_objects.modules.cooking_invoice_operations import CookingInvoiceOperations,CookingInvoice
from quick_resto_API.operations_with_objects.modules.cooking_place_operations import CookingPlaceOperations,CookingPlace
from quick_resto_API.operations_with_objects.modules.crm_customer_operations import CrmCustomerOperations,CrmCustomer
from quick_resto_API.operations_with_objects.modules.decomposition_invoice_operations import DecompositionInvoiceOperations,DecompositionInvoice
from quick_resto_API.operations_with_objects.modules.discard_invoice_operations import DiscardInvoiceOperations,DiscardInvoice
from quick_resto_API.operations_with_objects.modules.dish_operations import DishOperations,Dish,DishCategory
from quick_resto_API.operations_with_objects.modules.encashment_operations import EncashmentOperations,Encashment
from quick_resto_API.operations_with_objects.modules.exchange_invoice_operations import ExchangeInvoiceOperations,ExchangeInvoice
from quick_resto_API.operations_with_objects.modules.fixed_discount_operations import FixedDiscountOperations,FixedDiscount
from quick_resto_API.operations_with_objects.modules.incoming_invoice_operations import IncomingInvoiceOperations,IncomingInvoice
from quick_resto_API.operations_with_objects.modules.inventory_document_operations import InventoryDocumentOperations,InventoryDocument
from quick_resto_API.operations_with_objects.modules.kkm_terminal_operations import KkmTerminalOperations,KkmTerminal
from quick_resto_API.operations_with_objects.modules.markup_operations import MarkupOperations,Markup
from quick_resto_API.operations_with_objects.modules.measure_unit_operations import MeasureUnitOperations,MeasureUnit
from quick_resto_API.operations_with_objects.modules.modifier_operations import ModifierOperations,Modifier
from quick_resto_API.operations_with_objects.modules.order_discard_reason_operations import OrderDiscardReasonOperations,OrderDiscardReason
from quick_resto_API.operations_with_objects.modules.order_info_operations import OrderInfoOperations,OrderInfo
from quick_resto_API.operations_with_objects.modules.outgoing_invoice_operations import OutgoingInvoiceOperations,OutgoingInvoice
from quick_resto_API.operations_with_objects.modules.packing_unit_operations import PackingUnitOperations,PackingUnit
from quick_resto_API.operations_with_objects.modules.payment_type_operations import PaymentTypeOperations,PaymentType
from quick_resto_API.operations_with_objects.modules.pos_terminal_operations import PosTerminalOperations,PosTerminal
from quick_resto_API.operations_with_objects.modules.preorder_info_operations import PreorderInfoOperations,PreorderInfo
from quick_resto_API.operations_with_objects.modules.processing_invoice_operations import ProcessingInvoiceOperations,ProcessingInvoice
from quick_resto_API.operations_with_objects.modules.providers_operations import ProvidersOperations,ProviderGroup
from quick_resto_API.operations_with_objects.modules.raspberry_terminal_operations import RaspberryTerminalOperations,RaspberryTerminal
from quick_resto_API.operations_with_objects.modules.sale_place_operations import SalePlaceOperations,SalePlace
from quick_resto_API.operations_with_objects.modules.scheduled_discount_operations import ScheduledDiscountOperations,ScheduledDiscount
from quick_resto_API.operations_with_objects.modules.semi_product_operations import SemiProductOperations,SemiProduct
from quick_resto_API.operations_with_objects.modules.shift_operations import ShiftOperations,Shift
from quick_resto_API.operations_with_objects.modules.single_product_operations import SingleProductOperations,SingleCategory
from quick_resto_API.operations_with_objects.modules.store_item_tag_operations import StoreItemTagOperations,StoreItemTag
from quick_resto_API.operations_with_objects.modules.store_operations import StoreOperations,Store
from quick_resto_API.operations_with_objects.modules.table_scheme_operations import TableSchemeOperations,TableScheme
from quick_resto_API.operations_with_objects.modules.terminal_operations import TerminalOperations,Terminal
from quick_resto_API.operations_with_objects.modules.ticket_device_operations import TicketDeviceOperations,TicketDevice